@@ -173,6 +173,21 @@ class TestMutableMultiDict:
         d.add("key", "val1")
         d.add("key", "val2")
 
+        assert ("key", "val2") == d.popitem()
+        assert len(d) == 1
+        assert [("key", "val1")] == list(d.items())
+
+    def test_popitem2(
+        self,
+        case_sensitive_multidict_class: type[CIMultiDict[str]],
+    ) -> None:
+        d = case_sensitive_multidict_class()
+        d.add("key", "val1")
+        d.add("key", "val2")
+        d.add("key2", "val3")
+
+        del d["key2"]  # make dummy at the end
+
         assert ("key", "val2") == d.popitem()
         assert [("key", "val1")] == list(d.items())
 
@@ -365,6 +380,56 @@ class TestMutableMultiDict:
         with pytest.raises(TypeError):
             d.update("foo", "bar")  # type: ignore[arg-type, call-arg]
 
+    def test_repr_with_dummy(
+        self, case_sensitive_multidict_class: type[MultiDict[int]]
+    ) -> None:
+        d = case_sensitive_multidict_class({"a": 1, "b": 2, "c": 3})
+        cls = d.__class__.__name__
+        del d["b"]  # make a dummy entry
+        assert repr(d) == f"<{cls}('a': 1, 'c': 3)>"
+
+    def test_items_repr_with_dummy(
+        self, case_sensitive_multidict_class: type[MultiDict[int]]
+    ) -> None:
+        d = case_sensitive_multidict_class({"a": 1, "b": 2, "c": 3})
+        del d["b"]  # make a dummy entry
+        cls = d.items().__class__.__name__
+        assert repr(d.items()) == f"<{cls}('a': 1, 'c': 3)>"
+
+    def test_keys_repr_with_dummy(
+        self, case_sensitive_multidict_class: type[MultiDict[int]]
+    ) -> None:
+        d = case_sensitive_multidict_class({"a": 1, "b": 2, "c": 3})
+        del d["b"]  # make a dummy entry
+        cls = d.keys().__class__.__name__
+        assert repr(d.keys()) == f"<{cls}('a', 'c')>"
+
+    def test_values_repr_with_dummy(
+        self, case_sensitive_multidict_class: type[MultiDict[int]]
+    ) -> None:
+        d = case_sensitive_multidict_class({"a": 1, "b": 2, "c": 3})
+        del d["b"]  # make a dummy entry
+        cls = d.values().__class__.__name__
+        assert repr(d.values()) == f"<{cls}(1, 3)>"
+
+    def test_huge_md(
+        self,
+        case_sensitive_multidict_class: type[MultiDict[int]],
+    ) -> None:
+        size = 1 << 16
+        d = case_sensitive_multidict_class((str(i), i) for i in range(size))
+        assert d[str(size // 2)] == size // 2
+
+    def test_create_from_proxy(
+        self,
+        case_sensitive_multidict_class: type[MultiDict[int]],
+        case_sensitive_multidict_proxy_class: type[MultiDictProxy[int]],
+    ) -> None:
+        d = case_sensitive_multidict_class({"a": 1, "b": 2, "c": 3})
+        p = case_sensitive_multidict_proxy_class(d)
+        d2 = case_sensitive_multidict_class(p)
+        assert d2 == d
+
 
 class TestCIMutableMultiDict:
     def test_getall(
